
/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE GENERATOR WWW_KUPONY_RABATOWE_ID_GEN;

CREATE TABLE WWW_KUPONY_RABATOWE (
    ID               ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    NAZWA            STRING100_D /* STRING100_D = VARCHAR(100) */,
    TYP              INTEGER,
    KOD              STRING30_D /* STRING30_D = VARCHAR(30) */,
    RABAT            PROCENT_D /* PROCENT_D = NUMERIC(6,2) DEFAULT 0 CHECK  ((VALUE >=0) OR (VALUE IS NULL)) */,
    CENA_ID          SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    KWOTA            CENA_D /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    PROMOCJE         BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    DOSTAWA          BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    AKTYWNY          BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    WAZNY_OD         DATA_D /* DATA_D = DATE */,
    WAZNY_DO         DATA_D /* DATA_D = DATE */,
    ZK_KWOTA_MIN     WARTOSC_D DEFAULT 0 /* WARTOSC_D = NUMERIC(18,4) NOT NULL */,
    ZK_KWOTA_WALUTA  SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ZK_KWOTA_BRUTTO  BOOLEAN_D /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ILOSC_MAX        SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    ILOSC_KLIENT     SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    OPIS             BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    CDATE            DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */,
    MDATE            DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_KUPONY_RABATOWE ADD CONSTRAINT WWW_KUPONY_RABATOWE PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_KUPONY_RABATOWE_DATES_IND ON WWW_KUPONY_RABATOWE (CDATE, MDATE);
CREATE INDEX WWW_KUPONY_RABATOWE_DATY_IND ON WWW_KUPONY_RABATOWE (WAZNY_OD, WAZNY_DO);
CREATE INDEX WWW_KUPONY_RABATOWE_KOD_IND ON WWW_KUPONY_RABATOWE (KOD);
CREATE INDEX WWW_KUPONY_RABATOWE_NAZWA_IND ON WWW_KUPONY_RABATOWE (NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_KUPONY_RABATOWE_BI */
CREATE TRIGGER WWW_KUPONY_RABATOWE_BI FOR WWW_KUPONY_RABATOWE
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_KUPONY_RABATOWE_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/

/* Privileges of roles */
GRANT ALL ON WWW_KUPONY_RABATOWE TO WWW_ROLE;