DELETE FROM WWW_ZK WHERE ID NOT IN ( SELECT ID FROM GM_ZK );

CREATE GENERATOR WWW_ZAL_GRUPY_ID_GEN;
CREATE GENERATOR WWW_WEJSCIA_ID_GEN;
CREATE GENERATOR WWW_PROFILE_ID_GEN;
CREATE GENERATOR WWW_CENNIK_ID_GEN;
CREATE GENERATOR WWW_AUKCJE_ID_GEN;
CREATE GENERATOR WWW_CSV_ID_GEN;


CREATE DOMAIN WWW_SESJA_D AS CHAR(32) CHARACTER SET WIN1250 NOT NULL COLLATE WIN1250;


CREATE DOMAIN WWW_IDENT_D AS VARCHAR(15) CHARACTER SET WIN1250 COLLATE PXW_PLK;
CREATE DOMAIN ALLEGRO_LOGIN_D AS VARCHAR(16) CHARACTER SET WIN1250 COLLATE WIN1250;

CREATE TABLE WWW_ZAL_GRUPY (
  ID INTEGER NOT NULL,
  NAZWA STRING50_D NOT NULL,
  WYSWIETLANIE SMALLINT NOT NULL,
  CZAS_WYSWIETLANIA NUMERIC(12, 4),
  LICZBA_POBRAN INTEGER,
  UWAGI BLOB SUB_TYPE 2 SEGMENT SIZE 256,
  CDATE TIMESTAMP NOT NULL,
  MDATE TIMESTAMP NOT NULL);


ALTER TABLE WWW_ZAL_GRUPY ADD CONSTRAINT WWW_ZAL_GRUPY_PK PRIMARY KEY (ID);


CREATE UNIQUE INDEX WWW_ZAL_GRUPY_NAZWA_IND ON WWW_ZAL_GRUPY(NAZWA);

CREATE TABLE WWW_PROFILE (
  ID INTEGER NOT NULL,
  NAZWA STRING80_D NOT NULL,
  MANAGER BOOLEAN_D NOT NULL,
  AKWIZYTORZY BLOB SUB_TYPE 1 SEGMENT SIZE 256 CHARACTER SET WIN1250,
  GRUPAK_ID INTEGER,
  GRUPAK_EXT_ID INTEGER,
  UWAGI BLOB SUB_TYPE 1 SEGMENT SIZE 512 CHARACTER SET WIN1250,
  C_DATE DATA_TIME_D NOT NULL,
  M_DATE DATA_TIME_D NOT NULL,
  C_IDENT WWW_IDENT_D NOT NULL,
  M_IDENT WWW_IDENT_D NOT NULL);


ALTER TABLE WWW_PROFILE ADD CONSTRAINT WWW_PROFILE_PK PRIMARY KEY (ID);

ALTER TABLE WWW_PROFILE ADD CONSTRAINT WWW_PROFILE_GRUPAK_EXT_ID_FK FOREIGN KEY (GRUPAK_EXT_ID) REFERENCES R3_CONTACT_EXT_GROUPS(ID) ON DELETE SET NULL ON UPDATE CASCADE;

ALTER TABLE WWW_PROFILE ADD CONSTRAINT WWW_PROFILE_GRUPAK_ID_FK FOREIGN KEY (GRUPAK_ID) REFERENCES R3_CONTACT_GROUPS(ID) ON DELETE SET NULL ON UPDATE CASCADE;


CREATE INDEX WWW_PROFILE_CMIDENT_IND ON WWW_PROFILE(C_IDENT,M_IDENT);

CREATE INDEX WWW_PROFILE_DATY_IND ON WWW_PROFILE(C_DATE,M_DATE);

CREATE UNIQUE INDEX WWW_PROFILE_NAZWA_IND ON WWW_PROFILE(NAZWA);


CREATE TABLE WWW_ZAL_POBRANIA (
  ZAL_ID INTEGER NOT NULL,
  USER_ID INTEGER,
  KIEDY TIMESTAMP NOT NULL);


ALTER TABLE WWW_ZAL_POBRANIA ADD CONSTRAINT WWW_ZAL_POBRANIA_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS(ID) ON DELETE SET NULL ON UPDATE SET NULL;


CREATE INDEX WWW_ZAL_POBRANIA_KIEDY_IND ON WWW_ZAL_POBRANIA(KIEDY);

CREATE INDEX WWW_ZAL_POBRANIA_ZAL_ID_IND ON WWW_ZAL_POBRANIA(ZAL_ID);

ALTER TABLE WWW_ONLINE ADD WEJSCIE_ID INTEGER;

CREATE TABLE WWW_WEJSCIA (
  ID INTEGER NOT NULL,
  SESSION_ID CHAR(32) CHARACTER SET WIN1250 NOT NULL COLLATE WIN1250,
  USER_ID INTEGER,
  CONTACT_ID INTEGER,
  HOST VARCHAR(128) CHARACTER SET WIN1250 COLLATE WIN1250,
  URL STRING1024_D NOT NULL COLLATE WIN1250,
  REQUEST_URL STRING1024_D COLLATE WIN1250,
  ADRES_IP ADRES_IP_D,
  PRZEGLADARKA VARCHAR(200) CHARACTER SET WIN1250 COLLATE WIN1250,
  CZAS_WEJSCIA TIMESTAMP NOT NULL,
  ZK BOOLEAN_D NOT NULL);


ALTER TABLE WWW_WEJSCIA ADD CONSTRAINT WWW_WEJSCIA_PK PRIMARY KEY (ID);

ALTER TABLE WWW_WEJSCIA ADD CONSTRAINT WWW_WEJSCIA_CONTACT_ID FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_WEJSCIA ADD CONSTRAINT WWW_WEJSCIA_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS(ID) ON DELETE SET NULL ON UPDATE CASCADE;


CREATE INDEX WWW_WEJSCIA_ADRES_IP ON WWW_WEJSCIA(ADRES_IP);

CREATE INDEX WWW_WEJSCIA_CZAS_WEJSCIA_IND ON WWW_WEJSCIA(CZAS_WEJSCIA);

CREATE INDEX WWW_WEJSCIA_HOST_IND ON WWW_WEJSCIA(HOST,ZK);

CREATE INDEX WWW_WEJSCIA_PRZEGLDARKA_IND ON WWW_WEJSCIA(PRZEGLADARKA);

CREATE INDEX WWW_WEJSCIA_SESSION_ID_IND ON WWW_WEJSCIA(SESSION_ID);

CREATE INDEX WWW_WEJSCIA_ZK_IND ON WWW_WEJSCIA(ZK);


SET TERM  ^ ;

CREATE TRIGGER WWW_WEJSCIA_AI0 FOR WWW_WEJSCIA
ACTIVE AFTER INSERT
POSITION 0
AS
begin
  /* Trigger text */
  UPDATE WWW_ONLINE SET WEJSCIE_ID = NEW.ID WHERE SESSION_ID = NEW.SESSION_ID;
end ^

SET TERM ;  ^


CREATE TABLE WWW_PRIVS (
  USER_ID INTEGER,
  PROFIL_ID INTEGER,
  DOC_ID INTEGER,
  AKCJA VARCHAR(16) CHARACTER SET WIN1250 NOT NULL COLLATE WIN1250,
  PRIVS VARCHAR(8) CHARACTER SET WIN1250 NOT NULL COLLATE WIN1250,
  WIDOK SMALLINT NOT NULL,
  C_DATE DATA_TIME_D NOT NULL,
  M_DATE DATA_TIME_D);


ALTER TABLE WWW_PRIVS ADD CONSTRAINT WWW_PRIVS_PROFIL_ID_FK FOREIGN KEY (PROFIL_ID) REFERENCES WWW_PROFILE(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_PRIVS ADD CONSTRAINT WWW_PRIVS_USER_ID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_PRIVS ADD CONSTRAINT WWW_PRIVS_UNQ UNIQUE (USER_ID,PROFIL_ID,DOC_ID,AKCJA);


CREATE INDEX WWW_PRIVS_DATY_IND ON WWW_PRIVS(C_DATE,M_DATE);

CREATE INDEX WWW_PRIVS_DOC_ID_IND ON WWW_PRIVS(DOC_ID);

CREATE INDEX WWW_PRIVS_PRIVS_IND ON WWW_PRIVS(PRIVS);







CREATE TABLE WWW_CSV (
  ID INTEGER NOT NULL,
  NAZWA VARCHAR(128) CHARACTER SET WIN1250 NOT NULL COLLATE WIN1250,
  KODOWANIE STRING30_D,
  CENA_ID INTEGER NOT NULL,
  CENNIKI BLOB,
  POLA BLOB,
  SEPARATOR_TEKSTU CHAR_CODE_D NOT NULL,
  SEPARATOR_POLA CHAR_CODE_D NOT NULL,
  USE_CACHE BOOLEAN_D NOT NULL,
  CACHE_PERIOD INTEGER,
  UWAGI BLOB,
  CDATE TIMESTAMP,
  MDATE TIMESTAMP);


ALTER TABLE WWW_CSV ADD CONSTRAINT WWW_CSV_ID_PK PRIMARY KEY (ID);


CREATE INDEX WWW_CSV_DATY_IND ON WWW_CSV(CDATE,MDATE);

CREATE UNIQUE INDEX WWW_CSV_NAZWA_UNQ ON WWW_CSV(NAZWA);


CREATE TABLE WWW_CONTACTS (
  CONTACT_ID INTEGER NOT NULL,
  ALLEGRO_UID INTEGER,
  ALLEGRO_LOGIN ALLEGRO_LOGIN_D,
  ALLEGRO_RATING INTEGER);


ALTER TABLE WWW_CONTACTS ADD CONSTRAINT WWW_CONTACTS_CONTACT_ID_FK FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS(ID) ON DELETE CASCADE ON UPDATE CASCADE;


CREATE INDEX WWW_CONTACTS_ALLEGRO_LOGIN_IND ON WWW_CONTACTS(ALLEGRO_LOGIN);

CREATE INDEX WWW_CONTACTS_ALLEGRO_UID_IND ON WWW_CONTACTS(ALLEGRO_UID);

CREATE UNIQUE INDEX WWW_CONTACTS_CONTACT_ID ON WWW_CONTACTS(CONTACT_ID);


CREATE TABLE WWW_CENNIK (
  ID ID_D NOT NULL,
  ID_KONTRAHENTA SLOWNIK_D,
  ID_GRUPYK SLOWNIK_D,
  ID_PRODUCENTA SLOWNIK_D,
  ID_GRUPYT SLOWNIK_D,
  ID_SPOSOBU_PLATNOSCI SLOWNIK_D,
  ID_OPAKOWANIA SLOWNIK_D,
  INTERNET BOOLEAN_D DEFAULT 0 NOT NULL,
  NEWSLETTER BOOLEAN_D NOT NULL,
  IDCENY SLOWNIK_D,
  RODZAJ_RABATU SLOWNIK_D,
  RABAT PROCENT_D DEFAULT 0 NOT NULL,
  OPERATOR STRING15_D,
  DATAREJ DATA_TIME_D DEFAULT CURRENT_DATE NOT NULL,
  ZMIENIL STRING15_D,
  DATAZMIANY DATA_TIME_D DEFAULT CURRENT_DATE NOT NULL);


ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_PK PRIMARY KEY (ID);

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_IDCENY_FK FOREIGN KEY (IDCENY) REFERENCES GM_CENY(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_GRUPYK_FK FOREIGN KEY (ID_GRUPYK) REFERENCES R3_CONTACT_GROUPS(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_GRUPYT_FK FOREIGN KEY (ID_GRUPYT) REFERENCES GM_GRUPYT(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_KONTRAHENTA_FK FOREIGN KEY (ID_KONTRAHENTA) REFERENCES R3_CONTACTS(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_OPAKOWANIA_FK FOREIGN KEY (ID_OPAKOWANIA) REFERENCES GM_OPAKOWANIA(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_PRODUCENTA_FK FOREIGN KEY (ID_PRODUCENTA) REFERENCES R3_CONTACTS(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_ID_SP_PL_FK FOREIGN KEY (ID_SPOSOBU_PLATNOSCI) REFERENCES GM_SPOSOBY_ZAP(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_CENNIK ADD CONSTRAINT WWW_CENNIK_RODZ_RAB_FK FOREIGN KEY (RODZAJ_RABATU) REFERENCES GM_RABATY(ID) ON DELETE SET NULL ON UPDATE CASCADE;


CREATE INDEX WWW_CENNIK_DATY_IND ON WWW_CENNIK(DATAREJ,DATAZMIANY);


CREATE TABLE WWW_AUKCJE (
    ID                  INTEGER NOT NULL,
    SERWIS              VARCHAR(32) NOT NULL,
    SELLER_ID           SMALLINT,
    SELLER_LOGIN        ALLEGRO_LOGIN_D COLLATE PXW_PLK /* ALLEGRO_LOGIN_D = VARCHAR(16) */,
    CAT_ID              INTEGER NOT NULL,
    ITEM_ID             INTEGER NOT NULL,
    TOWAR_ID            INTEGER,
    AUCTION_TYPE        STRING10_D NOT NULL /* STRING10_D = VARCHAR(10) */,
    ITEM_NAME           STRING50_D NOT NULL /* STRING50_D = VARCHAR(50) */,
    TOWAR_NAZWA         STRING250_D NOT NULL /* STRING250_D = VARCHAR(250) */,
    STARTING_PRICE      CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    TPL                 VARCHAR(128),
    BUY_RESERVE_PRICE   CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    BUY_NOW_PRICE       CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    SELL_QUANTITY       ILOSC_D NOT NULL /* ILOSC_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    QUANTITY_TYPE       SMALLINT,
    DESCRIPTION         BLOB SUB_TYPE 2 SEGMENT SIZE 512,
    FUTURE_ACTIVE       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    AUCTION_DURATION    SMALLINT,
    COUNTRY             INTEGER,
    STATE               SMALLINT,
    LOCATION            STRING200_D /* STRING200_D = VARCHAR(200) */,
    TRANSPORT           VARCHAR(8),
    TRANSPORT_SHIPMENT  BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    WIRE_TRANSFER       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    POSTAGE_TRANSFER    BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    BOLD_TITLE          BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    LISTING_THUMB       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    HIGHLIGHT           BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    FEATURED            BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CATEGORY_PAGE       BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    ITEM_PRICE          CENA_D NOT NULL /* CENA_D = NUMERIC(15,4) DEFAULT 0 NOT NULL CHECK  (VALUE >=0) */,
    STARTING_TIME       INTEGER,
    HIGH_BIDDER         INTEGER,
    IS_ECO              BOOLEAN_NULL_D /* BOOLEAN_NULL_D = SMALLINT CHECK ((VALUE IS NULL) OR (VALUE IN (0,1))) */,
    HIT_COUNT           INTEGER,
    FIELDS              BLOB SUB_TYPE 1 SEGMENT SIZE 256,
    ATTRIBS             BLOB SUB_TYPE 2 SEGMENT SIZE 256,
    FOTOS               BLOB SUB_TYPE 2 SEGMENT SIZE 256,
    CDATE               TIMESTAMP NOT NULL,
    MDATE               TIMESTAMP NOT NULL,
    ARCHIVE             BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    KILLED              BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_AUKCJE ADD CONSTRAINT WWW_AUKCJE_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_AUKCJE ADD CONSTRAINT WWW_AUKCJE_TOWAR_ID_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY (ID) ON DELETE SET NULL ON UPDATE SET NULL;


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_AUKCJE_BI0 */
CREATE TRIGGER WWW_AUKCJE_BI0 FOR WWW_AUKCJE
ACTIVE BEFORE INSERT POSITION 0
AS
begin
  /* Trigger text */
 IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_AUKCJE_ID_GEN,1);
end
^


SET TERM ; ^




ALTER TABLE WWW_ZT ADD WEJSCIE_ID INTEGER;

ALTER TABLE WWW_ZK ADD AUKCJA_UID INTEGER;

ALTER TABLE WWW_ZK ADD AUKCJA_NUMER INTEGER;

ALTER TABLE WWW_ZK ADD PARTNER_ID INTEGER;

ALTER TABLE WWW_ZK ADD TEL STRING20_D COLLATE WIN1250;

ALTER TABLE WWW_ZK ADD EMAIL ADRES_EMAIL_D;

ALTER TABLE WWW_ZK ADD WEJSCIE_ID INTEGER;

ALTER TABLE WWW_USERS_CONFIG ADD SZABLON STRING200_D;

ALTER TABLE WWW_USERS ADD PROFIL_ID INTEGER;


ALTER TABLE WWW_KOSZYK_POZ ADD UWAGI BLOB SUB_TYPE 2;

update rdb$fields set
rdb$character_set_id = 51
where rdb$field_name = (select rf.rdb$field_source
from rdb$relation_fields rf
where (rf.rdb$field_name = 'NAZWA_SPOSOBU_DOSTAWY')
and (rf.rdb$relation_name = 'WWW_ZT'));

update rdb$fields set RDB$FIELD_SUB_TYPE = 1, rdb$character_set_id = 51
where rdb$field_name = (select rf.rdb$field_source
from rdb$relation_fields rf
where (rf.rdb$field_name = 'UWAGI')
and (rf.rdb$relation_name = 'WWW_ZT'));


update RDB$RELATION_FIELDS set
RDB$FIELD_SOURCE = 'STRING200_D'
where (RDB$FIELD_NAME = 'FIRMA_NAZWA') and
(RDB$RELATION_NAME = 'WWW_REG');

update rdb$fields set
rdb$character_set_id = 51
where rdb$field_name = (select rf.rdb$field_source
from rdb$relation_fields rf
where (rf.rdb$field_name = 'GUID')
and (rf.rdb$relation_name = 'WWW_REG'));

ALTER TABLE WWW_CONFIG
ALTER COLUMN GRUPA
TYPE VARCHAR(64) CHARACTER SET WIN1250;

CREATE INDEX WWW_ZK_AUKCJA_IND ON WWW_ZK(AUKCJA_NUMER,AUKCJA_UID);


ALTER TABLE WWW_USERS ADD CONSTRAINT WWW_USERS_PROFIL_ID_FK FOREIGN KEY (PROFIL_ID) REFERENCES WWW_PROFILE(ID) ON DELETE SET NULL ON UPDATE CASCADE;



GRANT ALL ON WWW_AUKCJE TO WWW_ROLE;
GRANT ALL ON WWW_CENNIK TO WWW_ROLE;
GRANT ALL ON WWW_CONFIG TO WWW_ROLE;
GRANT ALL ON WWW_CONTACTS TO WWW_ROLE;
GRANT ALL ON WWW_CSV TO WWW_ROLE;
GRANT ALL ON WWW_DB_VERSION TO WWW_ROLE;
GRANT ALL ON WWW_ERRORS TO WWW_ROLE;
GRANT ALL ON WWW_FAV TO WWW_ROLE;
GRANT ALL ON WWW_FAV_POZ TO WWW_ROLE;
GRANT ALL ON WWW_GRUPYT TO WWW_ROLE;
GRANT ALL ON WWW_GRUPYT_EXT TO WWW_ROLE;
GRANT ALL ON WWW_GRUPYT_SERWISY TO WWW_ROLE;
GRANT ALL ON WWW_HIST_LOGOWANIA TO WWW_ROLE;
GRANT ALL ON WWW_IP TO WWW_ROLE;
GRANT ALL ON WWW_KOMENTARZE TO WWW_ROLE;
GRANT ALL ON WWW_KOSZYK TO WWW_ROLE;
GRANT ALL ON WWW_KOSZYK_POZ TO WWW_ROLE;
GRANT ALL ON WWW_LOG TO WWW_ROLE;
GRANT ALL ON WWW_OFERTY TO WWW_ROLE;
GRANT ALL ON WWW_ONLINE TO WWW_ROLE;
GRANT ALL ON WWW_PARAMETRY TO WWW_ROLE;
GRANT ALL ON WWW_PARAM_GRUPY TO WWW_ROLE;
GRANT ALL ON WWW_PARAM_WART TO WWW_ROLE;
GRANT ALL ON WWW_POWIADOMIENIA TO WWW_ROLE;
GRANT ALL ON WWW_PRIVS TO WWW_ROLE;
GRANT ALL ON WWW_PROFILE TO WWW_ROLE;
GRANT ALL ON WWW_PRZESYLKI TO WWW_ROLE;
GRANT ALL ON WWW_PRZESYLKI_KOSZTY TO WWW_ROLE;
GRANT ALL ON WWW_PRZESYLKI_OPCJE TO WWW_ROLE;
GRANT ALL ON WWW_REG TO WWW_ROLE;
GRANT ALL ON WWW_SEARCH_HISTORY TO WWW_ROLE;
GRANT ALL ON WWW_SMS_LOG TO WWW_ROLE;
GRANT ALL ON WWW_SPOSOBY_DOSTAWY TO WWW_ROLE;
GRANT ALL ON WWW_STANY_UMOWNE TO WWW_ROLE;
GRANT ALL ON WWW_STATS TO WWW_ROLE;
GRANT ALL ON WWW_STRONY TO WWW_ROLE;
GRANT ALL ON WWW_SYNONIMY TO WWW_ROLE;
GRANT ALL ON WWW_TOWARY TO WWW_ROLE;
GRANT ALL ON WWW_TOWARY_PARAMS TO WWW_ROLE;
GRANT ALL ON WWW_USERS TO WWW_ROLE;
GRANT ALL ON WWW_USERS_CONFIG TO WWW_ROLE;
GRANT ALL ON WWW_UWAGI TO WWW_ROLE;
GRANT ALL ON WWW_WEJSCIA TO WWW_ROLE;
GRANT ALL ON WWW_WYRAZY TO WWW_ROLE;
GRANT ALL ON WWW_ZAL_GRUPY TO WWW_ROLE;
GRANT ALL ON WWW_ZAL_POBRANIA TO WWW_ROLE;
GRANT ALL ON WWW_ZK TO WWW_ROLE;
GRANT ALL ON WWW_ZK_FS2PA TO WWW_ROLE;
GRANT ALL ON WWW_ZT TO WWW_ROLE;
GRANT ALL ON WWW_ZT_POZ TO WWW_ROLE;
GRANT ALL ON WWW_NEWS TO WWW_ROLE;
