
/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_NEWSLETTER_GEN_ID;

CREATE TABLE WWW_NEWSLETTER (
    ID              ID_D NOT NULL /* ID_D = INTEGER DEFAULT 0 NOT NULL */,
    USER_ID         SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    CONTACT_ID      SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    PERSON_ID       SLOWNIK_D /* SLOWNIK_D = INTEGER */,
    EMAIL           ADRES_EMAIL_D NOT NULL /* ADRES_EMAIL_D = VARCHAR(64) */,
    INSTALACJA      WWW_INSTALACJA_D /* WWW_INSTALACJA_D = VARCHAR(30) */,
    GUID            GUID_D NOT NULL /* GUID_D = CHAR(36) */,
    CONFIRM         BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CONFIRM_DATE    DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */,
    SUBSCRIBE_DATE  DATA_TIME_D NOT NULL /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_NEWSLETTER ADD CONSTRAINT WWW_NEWSLETTER_UNQ UNIQUE (EMAIL, INSTALACJA);


/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_NEWSLETTER ADD CONSTRAINT PK_WWW_NEWSLETTER PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_NEWSLETTER ADD CONSTRAINT WWW_NEWSLETTER_CID_FK FOREIGN KEY (CONTACT_ID) REFERENCES R3_CONTACTS (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_NEWSLETTER ADD CONSTRAINT WWW_NEWSLETTER_PID_FK FOREIGN KEY (PERSON_ID) REFERENCES R3_PERSONS (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_NEWSLETTER ADD CONSTRAINT WWW_NEWSLETTER_UID_FK FOREIGN KEY (USER_ID) REFERENCES WWW_USERS (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_NEWSLETTER_DATY_IND ON WWW_NEWSLETTER (CONFIRM_DATE, SUBSCRIBE_DATE);
CREATE UNIQUE INDEX WWW_NEWSLETTER_GUID_IND ON WWW_NEWSLETTER (GUID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_NEWSLETTER_BI */
CREATE TRIGGER WWW_NEWSLETTER_BI FOR WWW_NEWSLETTER
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_NEWSLETTER_GEN_ID,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD ID TABLE WWW_NEWSLETTER
'Wzr typu dla pl zawierajcych identyfikator rekordu (musi zawiera warto)';

DESCRIBE FIELD USER_ID TABLE WWW_NEWSLETTER
'Wzr typu dla identyfikatora pozycji sownika danych';

DESCRIBE FIELD CONTACT_ID TABLE WWW_NEWSLETTER
'Wzr typu dla identyfikatora pozycji sownika danych';

DESCRIBE FIELD PERSON_ID TABLE WWW_NEWSLETTER
'Wzr typu dla identyfikatora pozycji sownika danych';

DESCRIBE FIELD GUID TABLE WWW_NEWSLETTER
'Wzr typu dla pl zawierajcych identyfikator typu GIUD, 36-znakowy acuch
znakw alfanumerycznych sucych do identyfikowania interfejsw';

DESCRIBE FIELD CONFIRM TABLE WWW_NEWSLETTER
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';

DESCRIBE FIELD CONFIRM_DATE TABLE WWW_NEWSLETTER
'Wzr typu dla pl zawierajcych dat';

DESCRIBE FIELD SUBSCRIBE_DATE TABLE WWW_NEWSLETTER
'Wzr typu dla pl zawierajcych dat';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_NEWSLETTER TO WWW_ROLE;
